@@ -5,7 +5,7 @@ import yaml
 import click
 from gama_cli.helpers import dacite_to_dict
 
-GAMA_GS_CONFIG_PATH = "config/gama_gs.yml"
+GAMA_GS_CONFIG_PATH = ".gama/gama_gs.yml"
 
 
 class Mode(str, Enum):
