@@ -27,7 +27,7 @@ from pathlib import Path
 import shutil
 
 
-GREENSTREAM_CONFIG_DEST_PATH = Path(".") / "config" / "greenstream"
+GREENSTREAM_CONFIG_DEST_PATH = Path(".") / ".gama" / "greenstream"
 GREENSTREAM_CONFIG_SOURCE_PATH = Path(__file__).parent.parent / "assets" / "greenstream"
 
 DOCKER_VESSEL = docker_compose_path("vessel/docker-compose.yaml")
@@ -84,10 +84,10 @@ class Vessel:
     def _get_greenstream_config(self, variant: Variant, mode: Mode):
         if mode == Mode.STUBS:
             return "config.stubs.yml"
-        if mode == Mode.SIM:
+        if mode == Mode.SIMULATOR:
             print("SIM VIDEO STREAMING NO LONGER SUPPORTED")
             return "config.sim.yml"
-        if mode == Mode.HW:
+        if mode == Mode.HARDWARE:
             if variant == Variant.WHISKEY_BRAVO:
                 return "config.variant.bravo.yml"
             if variant == Variant.EDUCAT:
@@ -370,7 +370,7 @@ class Vessel:
                 ubiquity_pass=click.prompt("Ubiquity password", default=""),
                 ubiquity_ip=click.prompt("Ubiquity ip", default=""),
                 mode=click.prompt(
-                    "Mode", default=Mode.HW, type=click.Choice([item.value for item in Mode])
+                    "Mode", default=Mode.HARDWARE, type=click.Choice([item.value for item in Mode])
                 ),
                 prod=click.prompt("Prod", default=True, type=bool),
                 log_level=click.prompt(
@@ -396,5 +396,7 @@ class Vessel:
                 if result == "n":
                     return
 
-            # Copy the directory from the assets f
-            shutil.copytree(GREENSTREAM_CONFIG_SOURCE_PATH, GREENSTREAM_CONFIG_DEST_PATH)
+            # Copy the directory from the assets. If it exists, it will be overwritten
+            shutil.copytree(
+                GREENSTREAM_CONFIG_SOURCE_PATH, GREENSTREAM_CONFIG_DEST_PATH, dirs_exist_ok=True
+            )
